@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.3.0';
+our $VERSION = '1.3.1';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -112,8 +112,6 @@ has ua                      => sub {
 };
 
 has message_queue => sub{$_[0]->gen_message_queue()};
-
-has sync_key => sub{+{}};
 has pass_ticket => '';
 has skey => '';
 has wxsid => '';
@@ -126,6 +124,18 @@ has _synccheck_running => 0;
 has _synccheck_error_count => 0;
 has _synccheck_connection_id => undef;
 
+has sync_key => sub{+{List=>[]}};
+sub synccheck_key {
+    my $self = shift;
+    if(@_==0){
+        return $self->{synccheck_key} // $self->sync_key;
+    }
+    else{
+        $self->{synccheck_key} = $_[0];
+        return $self;
+    }
+}
+
 sub deviceid { return "e" . substr(rand() . ("0" x 15),2,15);}
 sub state {
     my $self = shift;
@@ -209,6 +219,7 @@ sub new {
         $self->error(Carp::longmess($err));
     });
     $self->check_pid();
+    $self->load_cookie();
     $self->save_state();
     $SIG{CHLD} = 'IGNORE';
     $SIG{INT}  = $SIG{TERM} = $SIG{HUP} = sub{
