@@ -168,15 +168,15 @@ sub load_cookie{
     my $cookie_jar;
     my $cookie_path = $self->cookie_path;
     return if not -f $cookie_path;
-    eval{require Storable;$cookie_jar = Storable::retrieve($cookie_path)};
+    eval{$cookie_jar = Storable::retrieve($cookie_path);};
     if($@){
         $self->warn("客户端加载cookie[ $cookie_path ]失败: $@");
         return;
     }
     else{
         $self->info("客户端加载cookie[ $cookie_path ]");
+        $self->ua->cookie_jar($cookie_jar);
     }
-    $self->ua->cookie_jar($cookie_jar);
 
 }
 sub save_cookie{
